@@ -49,6 +49,8 @@ if( !class_exists('CGPaymentGatewayBase') )
 }
 
 
+define('AUTHNETARB_PRODUCTION_URL','https://api.authorize.net/xml/v1/request.api');
+define('AUTHNETARB_TEST_URL','https://apitest.authorize.net/xml/v1/request.api');
 define('AUTHNETAIM_SECURE_POST_URL','https://secure.authorize.net/gateway/transact.dll');
 define('AUTHNETAIM_TEST_POST_URL','https://test.authorize.net/gateway/transact.dll');
 
@@ -90,7 +92,7 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function GetVersion()
   {
-    return '1.2.6';
+    return '1.3';
   }
 
 
@@ -153,8 +155,6 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function GetAdminSection()
   {
-    global $CMS_VERSION;
-    if( version_compare($CMS_VERSION,'1.8','<') ) return 'extensions';
     return 'ecommerce';
   }
 
@@ -183,8 +183,8 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function GetDependencies()
   {
-    return array('CGPaymentGatewayBase'=>'1.0.5',
-		 'CGExtensions'=>'1.18.3');
+    return array('CGPaymentGatewayBase'=>'1.0.10',
+		 'CGExtensions'=>'1.24');
   }
 
 
@@ -193,7 +193,7 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function MinimumCMSVersion()
   {
-    return "1.8.2";
+    return "1.9.2";
   }
 
 
@@ -340,6 +340,8 @@ class AuthNetAim extends CGPaymentGatewayBase
    ---------------------------------------------------------*/
   public function SetCreditCardInfo($ccnumber,$ccexp,$ccvcode)
   {
+    $this->_data['raw_ccinfo'] = array($ccnumber,$ccexp,$ccvcode);
+
     $_ccinfo = array();
     $_ccinfo['x_card_num'] = preg_replace('([^0-9])','',$ccnumber);
     $_ccinfo['x_exp_date'] = date('m',$ccexp).'/'.date('Y',$ccexp);
@@ -421,6 +423,25 @@ class AuthNetAim extends CGPaymentGatewayBase
   }
 
 
+  /*---------------------------------------------------------
+   SetOrderObject()
+   ---------------------------------------------------------*/
+  function SetOrderObject(orders_order& $order)
+  {
+    $this->_data['order_obj'] = $order;
+  }
+
+
+  /*---------------------------------------------------------
+   get_order_object()
+   ---------------------------------------------------------*/
+  protected function &get_order_object()
+  {
+    if( isset($this->_data['order_obj']) )
+      return $this->_data['order_obj'];
+  }
+
+
   /*---------------------------------------------------------
    SetOrderTaxAmount()
    ---------------------------------------------------------*/
@@ -487,6 +508,37 @@ class AuthNetAim extends CGPaymentGatewayBase
   }
 
 
+  /*---------------------------------------------------------
+   SetTransactionData()
+   ---------------------------------------------------------*/
+  protected function SetTransactionData($key,$value)
+  {
+    if( !isset($this->_data['transdata']) ) $this->_data['transdata'] = array();
+    $this->_data['transdata'][$key] = $value;
+  }
+
+
+  /*---------------------------------------------------------
+   GetTransactionKeys()
+   ---------------------------------------------------------*/
+  public function GetTransactionKeys()
+  {
+    if( !isset($this->_data['transdata']) ) return;
+    return array_keys($this->_data['transdata']);
+  }
+
+
+  /*---------------------------------------------------------
+   GetTransactionData()
+   ---------------------------------------------------------*/
+  public function GetTransactionData($key,$dflt = '')
+  {
+    if( !isset($this->_data['transdata']) ) return $dflt;
+    if( !isset($this->_data['transdata'][$key]) )  return $dflt;
+    return $this->_data['transdata'][$key];
+  }
+
+
   /*---------------------------------------------------------
    SetTransactionAmount()
    ---------------------------------------------------------*/
@@ -673,8 +725,8 @@ class AuthNetAim extends CGPaymentGatewayBase
 
   function GetNotificationOutput($priority=2)
   {
-    global $CMS_ADMIN_PAGE;
     $testmode = $this->GetPreference('testmode',1);
+    $devacct = $this->GetPreference('usetesturl',0);
     if( $testmode && check_login(FALSE) )
       {
 	$data = new stdClass;
@@ -682,5 +734,31 @@ class AuthNetAim extends CGPaymentGatewayBase
 	$data->html = $this->ShowErrors($this->Lang('msg_testmode'));
 	return $data;
       }
+    else if( $devacct )
+      {
+	$data = new stdClass;
+	$data->priority = 1;
+	$data->html = $this->ShowErrors($this->Lang('msg_devacct'));
+	return $data;
+      }
+  }
+
+
+  /*---------------------------------------------------------
+   get_cartitem_policy()
+   ---------------------------------------------------------*/
+  public function get_cartitem_policy()
+  {
+    $policy = new cg_ecomm_cartitem_policy;
+    if( $this->GetPreference('allow_subscriptions') )
+      {
+	$policy->set_max_subscriptions(1);
+      }
+    else
+      {
+	$policy->set_max_subscriptions(0);
+      }
+    $policy->set_mixed_subscriptions(FALSE);
+    return $policy;
   }
 } // class
