@@ -61,6 +61,15 @@ if( !isset($this->_data['ccinfo']) ||
     return;
   }
 
+if( $this->order_contains_subscription() )
+  {
+    // we have a subscription, and have done all our checks
+    // so another file will handle it.
+    include(dirname(__FILE__).'/function.process_subscription.inc.php');
+    return;
+  }
+
+
 $billing = $this->_data['billing_address'];
 $shipping = $this->_data['shipping_address'];
 if( !is_object($billing) || !is_object($shipping) )
@@ -70,6 +79,7 @@ if( !is_object($billing) || !is_object($shipping) )
     return;
   }
 
+
 //  
 // setup
 //
@@ -102,7 +112,6 @@ if( $this->GetPreference('usetesturl') )
 //
 // build our data
 //
-
 // a) calculate total amount of order
 if( isset($this->_data['ordertax']) && isset($this->_data['ordershipping']) )
   $amount = $this->_data['ordertax'] + $this->_data['ordershipping'];
