@@ -1,8 +1,9 @@
 <?php
 #A
 $lang['advanced'] = 'Advanced';
-$lang['alternate_post_url'] = 'Alternate Transaction Submission URL';
-$lang['alternate_test_url'] = 'Alternate Test Transaction Submission URL';
+$lang['alternate_post_url'] = 'Alternate Production Submission URL';
+$lang['alternate_test_url'] = 'Alternate Development Submission URL';
+$lang['alternate_arb_url'] = 'Alternative Production ARB URL';
 
 
 #B
@@ -21,11 +22,12 @@ $lang['error_held_for_review'] = 'Payment has been held for review';
 $lang['error_missing_data'] = 'Some information required for successfull transaction processing is not set';
 $lang['error_payment_declined'] = 'Payment has been declined';
 $lang['error_restoring_state'] = 'A problem occurred restoring gateway state information';
+$lang['error_transaction_error'] = 'Error %s occurred processing transaction: %s';
 $lang['error_unknown'] = 'The payment gateway returned information we dont understand at this time';
 
 
 #F
-$lang['friendlyname'] = 'Authorize.net AIM';
+$lang['friendlyname'] = 'Authorize.net AIM/ARB';
 $lang['form_template'] = 'Form Template';
 
 #G
@@ -41,7 +43,9 @@ $lang['help'] = <<<EOT
 <p>This module requires that your web application be configured to prompt the user for credit card information, The Orders module can be configured to do this.</p>
 <p>Also this module will require a validated secure environment.   You will need to purchase a validated certificate from an approvded provider, install that certificate in your web host environment, and then configure CMS Made Simple to work properly in a secure environment.</p>
 <h3>How do I use it?</h3>
-<p>Quite simply, once all of the dependencies are installed, you simply install the module.  Then configure the module in the Authorize.NET AIM control panel in the CMS Made Simple admin console, using the transaction id, and the API Login that are provided to you by authorize.net. Then navigate to the preferences tab in the Orders module and select this module as your chosen payment gateway.</p>
+<p>Quite simply, once all of the dependencies are installed, you simply install the module.  Then configure the module in the Authorize.NET AIM/ARB control panel in the CMS Made Simple admin console, using the transaction id, and the API Login that are provided to you by authorize.net. Then navigate to the preferences tab in the CGPaymentGateway Base module and select this module as your chosen payment gateway.</p>
+<h3>Subscriptions:</h3>
+<p>This module has limited support for subscriptions (For example membership subscriptions, or product subscriptions).  It will create a subscription within the Authorize.NET Merchant center as a user checks out, and will provide information on declined payments, etc. to the Orders module via the Authorize.NET Silent POST URL.  However, There is no means by which a visitor can cancel a subscription from within the website, and there is no way that the orders module can know about subscriptions manually added, edited, or deleted within the Authorize.NET merchant center.</p>
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
@@ -74,10 +78,12 @@ EOT;
 
 
 #I
+$lang['info_allow_subscriptions'] = 'Enable this if you have a properly configured <a href="http://authorize.net">Authorize.Net</a> account, with ARB Access, and yuu would like to sell either products or services as a subscription.';
 $lang['info_alternate_urls'] = 'Some payment gateways have &quot;Authorize.NET&quot; emulators to allow using that payment gateway with alternate software.   Along with other details, they will provide alternate URLS for submitting the transactions.   You may specify those URLS here.   If these values are blank, then the system default URLS are used';
 $lang['info_md5hash'] = 'The key used to encrypt certain information about the transaction, and to verify that transaction information came from a valid server.   You should configure the identical value in your authorize.net settings';
 $lang['info_loginid'] = 'Please enter the Login ID provided to you by your authorize.net reseller';
-$lang['info_testmode'] = 'With test mode enabled, no real transactions will be processed for logged in administrators.';
+$lang['info_silent_post_url'] = 'Copy this URL into the &quot;SILENT POST&quot; URL field in your Authorize.NET merchant center.  If this URL is not specified, the system will not receive notification of cancelled subscriptions or other errors.';
+$lang['info_testmode'] = 'With test mode enabled, no real transactions will be processed for logged in administrators.  This option has no effect on ARB (subscription) transactions.';
 $lang['info_transactionkey'] = 'The transaction key value supplied to you by your authorize.net reseller';
 $lang['info_usetesturl'] = 'Use the Authorize.net development environment instead of the real environment (requires having a developer account)';
 
@@ -91,8 +97,9 @@ $lang['info_usetesturl'] = 'Use the Authorize.net development environment instea
 
 
 #M
-$lang['moddescription'] = 'A payment gateway for the E-commerce system that uses the AIM protocol from Authorize.net';
-$lang['msg_testmode'] = 'Test mode is enabled for logged in administrators';
+$lang['moddescription'] = 'A payment gateway for the E-commerce system that uses the AIM and ARB protocols from Authorize.net';
+$lang['msg_devacct'] = 'Authorize.NET AIM/ARB - Using developer account... no real transactions will be processed';
+$lang['msg_testmode'] = 'Authorize.NET AIM/ARB - Test mode is enabled for logged in administrators';
 
 #N
 
@@ -104,9 +111,11 @@ $lang['msg_testmode'] = 'Test mode is enabled for logged in administrators';
 $lang['postinstall'] = 'Module successfully installed.  Please visit the module admin panel and ensure all preferences are set properly';
 $lang['postuninstall'] = 'This module has been successfully uninstalled';
 $lang['preferences'] = 'Preferences';
+$lang['prompt_allow_subscriptions'] = 'Allow Subscriptions';
 $lang['prompt_form_template'] = 'Edit the Form Template';
 $lang['prompt_md5hash'] = 'MD5 Hash';
 $lang['prompt_loginid'] = 'Authorize.Net API Login ID';
+$lang['prompt_silent_post_url'] = 'Silent POST URL';
 $lang['prompt_testmode'] = 'Enable Test Mode';
 $lang['prompt_transactionkey'] = 'Transaction Key';
 $lang['prompt_usetesturl'] = 'Use Developer account';
@@ -120,8 +129,8 @@ $lang['really_uninstall'] = 'Are you sure you want to uninstall this module.  Co
 #S
 $lang['submit'] = 'Submit';
 
-
 #T
+$lang['test_arb_url'] = 'Alternative Development ARB URL';
 
 #U
 
